# HydroSAR for Python

[![PyPI license](https://img.shields.io/pypi/l/hydrosar.svg)](https://pypi.python.org/pypi/hydrosar/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/hydrosar.svg)](https://pypi.python.org/pypi/hydrosar/)
[![PyPI version](https://img.shields.io/pypi/v/hydrosar.svg)](https://pypi.python.org/pypi/hydrosar/)
[![Conda version](https://img.shields.io/conda/vn/conda-forge/hydrosar)](https://anaconda.org/conda-forge/hydrosar)
[![Conda platforms](https://img.shields.io/conda/pn/conda-forge/hydrosar)](https://anaconda.org/conda-forge/hydrosar)

[`hydrosar`](src/hydrosar) is a Python package developed for generating HydroSAR products, both locally and in [ASF's HyP3](https://hyp3-docs.asf.alaska.edu/).

## Install

In order to easily manage dependencies, we recommend using dedicated project
environments via [Anaconda/Miniconda](https://docs.conda.io/projects/conda/en/latest/user-guide/install/index.html).
It is also possible to use [Python virtual environments](https://docs.python.org/3/tutorial/venv.html),
but installation of non-python dependencies (e.g., `gdal`) can be challenging. 

`hydrosar` can be installed into a conda environment with:

```
conda install -c conda-forge hydrosar
```

or into a virtual environment with:

```
python -m pip install hydrosar
```

### Running as a Docker container

We also publish a [Docker](https://docs.docker.com/get-started/) image for `hydrosar`, with all the dependencies
pre-installed, to the GitHub Container Registry:
<https://github.com/fjmeyer/HydroSAR/pkgs/container/hydrosar>.

You can pull an image with the latest released version of `hydrosar`  with the command:
```
docker pull ghcr.io/fjmeyer/hydrosar:latest
```

Or, the development version with: 
```
docker pull ghcr.io/fjmeyer/hydrosar:test
```

And then run the container with:
```
docker run --rm -it ghcr.io/fjmeyer/hydrosar:latest --help
```

To move data between your local (host) machine and the container, you can mount a 
[volume](https://docs.docker.com/storage/volumes/) with:
```
docker run --rm -it -v /path/to/data:/home/conda/data ghcr.io/fjmeyer/hydrosar:latest
```

## Quick Usage

### HYDRO30: Surface Water Extent Mapping

The `make_HYDRO30` tool allows you to create a surface water extent map from a Sentinel-1
dual-pol (VV+VH) RTC product. It is intended to be used with RTC products generated by
[ASF HyP3](https://hyp3-docs.asf.alaska.edu/using/vertex).

Additionally, a HAND (height above nearest drainage) GeoTIFF that is pixel aligned to
the RTC images is required, and preferably derived from the same DEM used to correct
the RTC images -- the quality of the HAND used is directly tied to the quality of the
output water extent map.

To make a water extent map, run:
```
make_HYDRO30 [OUT_RASTER] [VV_RASTER] [VH_RASTER] [HAND_RASTER]
```

For more information and to see the options available, see:
```
make_HYDRO30 --help
```

For details on the algorithm see the `hydrosar.water_map.make_water_map` docstring.

### Flood depth mapping

> [!WARNING]
> The flood depth tool is still under active development and the products
created using this tool are likely to change in the future.

The `make_FD30` tool allows you to create an estimated flood depth map from the surface
water extent map created by the `make_HYDRO30` tool. 

Additionally, a HAND (height above nearest drainage) GeoTIFF that is pixel aligned to
the surface water extent map is required. An ideal candidate is the HAND image created 
by the `make_HYDRO30` tool. 

To make a flood depth map, run:
```
make_FD30 [OUT_RASTER] [SURFACE_WATER_MAP] [HAND_RASTER]
```

For more information and to see the options available, see:
```
make_FD30 --help
```

For details on the algorithm see the `hydrosar.flood_map.make_flood_map` docstring.
